"""PerMachineSettings"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
)
from mastapy._private.utility import _1769

_PER_MACHINE_SETTINGS = python_net_import("SMT.MastaAPI.Utility", "PerMachineSettings")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.bearings import _2085
    from mastapy._private.gears.gear_designs.cylindrical import _1114
    from mastapy._private.gears.ltca.cylindrical import _951
    from mastapy._private.gears.materials import _683
    from mastapy._private.nodal_analysis import _71
    from mastapy._private.nodal_analysis.geometry_modeller_link import _232
    from mastapy._private.system_model.part_model import _2644, _2669
    from mastapy._private.utility import _1770, _1771
    from mastapy._private.utility.cad_export import _2017
    from mastapy._private.utility.databases import _2009
    from mastapy._private.utility.scripting import _1917
    from mastapy._private.utility.units_and_measurements import _1781

    Self = TypeVar("Self", bound="PerMachineSettings")
    CastSelf = TypeVar("CastSelf", bound="PerMachineSettings._Cast_PerMachineSettings")


__docformat__ = "restructuredtext en"
__all__ = ("PerMachineSettings",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_PerMachineSettings:
    """Special nested class for casting PerMachineSettings to subclasses."""

    __parent__: "PerMachineSettings"

    @property
    def persistent_singleton(self: "CastSelf") -> "_1769.PersistentSingleton":
        return self.__parent__._cast(_1769.PersistentSingleton)

    @property
    def fe_user_settings(self: "CastSelf") -> "_71.FEUserSettings":
        from mastapy._private.nodal_analysis import _71

        return self.__parent__._cast(_71.FEUserSettings)

    @property
    def geometry_modeller_settings(self: "CastSelf") -> "_232.GeometryModellerSettings":
        from mastapy._private.nodal_analysis.geometry_modeller_link import _232

        return self.__parent__._cast(_232.GeometryModellerSettings)

    @property
    def gear_material_expert_system_factor_settings(
        self: "CastSelf",
    ) -> "_683.GearMaterialExpertSystemFactorSettings":
        from mastapy._private.gears.materials import _683

        return self.__parent__._cast(_683.GearMaterialExpertSystemFactorSettings)

    @property
    def cylindrical_gear_fe_settings(
        self: "CastSelf",
    ) -> "_951.CylindricalGearFESettings":
        from mastapy._private.gears.ltca.cylindrical import _951

        return self.__parent__._cast(_951.CylindricalGearFESettings)

    @property
    def cylindrical_gear_defaults(self: "CastSelf") -> "_1114.CylindricalGearDefaults":
        from mastapy._private.gears.gear_designs.cylindrical import _1114

        return self.__parent__._cast(_1114.CylindricalGearDefaults)

    @property
    def program_settings(self: "CastSelf") -> "_1770.ProgramSettings":
        from mastapy._private.utility import _1770

        return self.__parent__._cast(_1770.ProgramSettings)

    @property
    def pushbullet_settings(self: "CastSelf") -> "_1771.PushbulletSettings":
        from mastapy._private.utility import _1771

        return self.__parent__._cast(_1771.PushbulletSettings)

    @property
    def measurement_settings(self: "CastSelf") -> "_1781.MeasurementSettings":
        from mastapy._private.utility.units_and_measurements import _1781

        return self.__parent__._cast(_1781.MeasurementSettings)

    @property
    def scripting_setup(self: "CastSelf") -> "_1917.ScriptingSetup":
        from mastapy._private.utility.scripting import _1917

        return self.__parent__._cast(_1917.ScriptingSetup)

    @property
    def database_settings(self: "CastSelf") -> "_2009.DatabaseSettings":
        from mastapy._private.utility.databases import _2009

        return self.__parent__._cast(_2009.DatabaseSettings)

    @property
    def cad_export_settings(self: "CastSelf") -> "_2017.CADExportSettings":
        from mastapy._private.utility.cad_export import _2017

        return self.__parent__._cast(_2017.CADExportSettings)

    @property
    def skf_settings(self: "CastSelf") -> "_2085.SKFSettings":
        from mastapy._private.bearings import _2085

        return self.__parent__._cast(_2085.SKFSettings)

    @property
    def default_export_settings(self: "CastSelf") -> "_2644.DefaultExportSettings":
        from mastapy._private.system_model.part_model import _2644

        return self.__parent__._cast(_2644.DefaultExportSettings)

    @property
    def planet_carrier_settings(self: "CastSelf") -> "_2669.PlanetCarrierSettings":
        from mastapy._private.system_model.part_model import _2669

        return self.__parent__._cast(_2669.PlanetCarrierSettings)

    @property
    def per_machine_settings(self: "CastSelf") -> "PerMachineSettings":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class PerMachineSettings(_1769.PersistentSingleton):
    """PerMachineSettings

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _PER_MACHINE_SETTINGS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    def reset_to_defaults(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "ResetToDefaults")

    @property
    def cast_to(self: "Self") -> "_Cast_PerMachineSettings":
        """Cast to another type.

        Returns:
            _Cast_PerMachineSettings
        """
        return _Cast_PerMachineSettings(self)
